@@ -31,11 +31,7 @@
 #include <QWidget>
 
 #include <KAboutData>
-#include <KWindowSystem>
-
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
 #include <KX11Extras>
-#endif
 
 using namespace Amarok;
 
@@ -62,11 +58,7 @@ void MediaPlayer2::Raise() const
         return;
     }
     window->show();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    KWindowSystem::forceActiveWindow( window->winId() );
-#else
     KX11Extras::forceActiveWindow( window->winId() );
-#endif
 }
 
 bool MediaPlayer2::CanQuit() const
