@@ -63,7 +63,6 @@
 #include <QPalette>
 #include <QPersistentModelIndex>
 #include <QScrollBar>
-#include <QSvgRenderer>
 #include <QTimer>
 #include <QUrl>
 
@@ -163,7 +162,7 @@ void
 Playlist::PrettyListView::editTrackInformation()
 {
     Meta::TrackList tl;
-    foreach( const QModelIndex &index, selectedIndexes() )
+    for( const QModelIndex &index : selectedIndexes() )
     {
         tl.append( index.data( TrackRole ).value<Meta::TrackPtr>() );
     }
@@ -195,7 +194,7 @@ Playlist::PrettyListView::removeSelection()
 
         // Next, we look for the first row.
         int firstRow = sr.first();
-        foreach( int i, sr )
+        for( int i : sr )
         {
             if( i < firstRow )
                 firstRow = i;
@@ -469,24 +468,28 @@ Playlist::PrettyListView::dragEnterEvent( QDragEnterEvent *event )
         mime->hasFormat( AmarokMimeData::PODCASTEPISODE_MIME ) ||
         mime->hasFormat( AmarokMimeData::PODCASTCHANNEL_MIME ) )
     {
-        event->acceptProposedAction();
+        if( !(ModelStack::instance()->sortProxy()->isSorted() && qobject_cast<PrettyListView*>( event->source() ) == this) )
+            event->acceptProposedAction();
     }
 }
 
 void
 Playlist::PrettyListView::dragMoveEvent( QDragMoveEvent* event )
 {
-    QModelIndex index = indexAt( event->pos() );
-    if ( index.isValid() )
+    if( !(ModelStack::instance()->sortProxy()->isSorted() && qobject_cast<PrettyListView*>( event->source() ) == this) )
     {
-        m_dropIndicator = visualRect( index );
-    }
-    else
-    {
-        // draw it on the bottom of the last item
-        index = model()->index( model()->rowCount() - 1, 0, QModelIndex() );
-        m_dropIndicator = visualRect( index );
-        m_dropIndicator = m_dropIndicator.translated( 0, m_dropIndicator.height() );
+        QModelIndex index = indexAt( event->pos() );
+        if ( index.isValid() )
+        {
+            m_dropIndicator = visualRect( index );
+        }
+        else
+        {
+            // draw it on the bottom of the last item
+            index = model()->index( model()->rowCount() - 1, 0, QModelIndex() );
+            m_dropIndicator = visualRect( index );
+            m_dropIndicator = m_dropIndicator.translated( 0, m_dropIndicator.height() );
+        }
     }
     QListView::dragMoveEvent( event );
 }
@@ -505,7 +508,7 @@ Playlist::PrettyListView::dropEvent( QDropEvent* event )
         QList<int> sr = selectedRows();
         int realtarget = The::playlistController()->moveRows( sr, targetRow );
         QItemSelection selItems;
-        foreach( int row, sr )
+        for( int row : sr )
         {
             Q_UNUSED( row )
             selItems.select( plModel->index( realtarget, 0 ), plModel->index( realtarget, 0 ) );
@@ -587,7 +590,7 @@ Playlist::PrettyListView::mousePressEvent( QMouseEvent* event )
         m_mousePressInHeader = false;
     }
 
-    if ( event->button() == Qt::MidButton )
+    if ( event->button() == Qt::MiddleButton )
     {
         QUrl url( QApplication::clipboard()->text() );
         if ( url.isValid() )
@@ -728,7 +731,7 @@ Playlist::PrettyListView::startDrag( Qt::DropActions supportedActions )
         qDebug() << "does play exist in renderer? " << ( The::svgHandler()->getRenderer( QStringLiteral("amarok/images/pud_items.svg") )->elementExists( QStringLiteral("load") ) );
 
         QList<QAction*> actions =  actionsFor( this, &indices.first() );
-        foreach( QAction * action, actions )
+        for( QAction * action : actions )
             m_pd->addItem( The::popupDropperFactory()->createItem( action ), true );
 
         m_pd->show();
@@ -793,7 +796,7 @@ QList<int>
 Playlist::PrettyListView::selectedRows() const
 {
     QList<int> rows;
-    foreach( const QModelIndex &idx, selectedIndexes() )
+    for( const QModelIndex &idx : selectedIndexes() )
         rows.append( idx.row() );
     return rows;
 }
