@@ -34,7 +34,10 @@
 
 #include <QAction>
 #include <QLabel>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkConfigurationManager>
+#endif
 #include <QTimer>
 
 #include <KIO/TransferJob>
@@ -447,8 +450,10 @@ void GpodderProvider::synchronizeStatus()
 
     debug() << "new episodes status: " << m_uploadEpisodeStatusMap.size();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if( !QNetworkConfigurationManager().isOnline() )
         return;
+#endif
 
     if( !m_uploadEpisodeStatusMap.isEmpty() )
     {
@@ -513,8 +518,10 @@ GpodderProvider::synchronizeSubscriptions()
     debug() << "add: " << m_addList.size();
     debug() << "remove: " << m_removeList.size();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if( !QNetworkConfigurationManager().isOnline() )
         return;
+#endif
 
     if( !m_removeList.isEmpty() || !m_addList.isEmpty() )
     {
@@ -690,11 +697,13 @@ GpodderProvider::requestDeviceUpdates()
 {
     DEBUG_BLOCK
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if( !QNetworkConfigurationManager().isOnline() )
     {
         QTimer::singleShot( 10000, this, SLOT(requestDeviceUpdates()) );
         return;
     }
+#endif
 
     m_deviceUpdatesResult =
             m_apiRequest->deviceUpdates( m_username,
@@ -793,11 +802,13 @@ GpodderProvider::requestEpisodeActionsInCascade()
 {
     DEBUG_BLOCK
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if( !QNetworkConfigurationManager().isOnline() )
     {
         QTimer::singleShot( 10000, this, SLOT(requestEpisodeActionsInCascade()) );
         return;
     }
+#endif
 
     //This function will download all episode actions for
     //every podcast contained in m_channelsToRequestActions
