@@ -21,7 +21,7 @@
 #include "core/transcoding/TranscodingConfiguration.h"
 
 #include <KJob>
-#include <KUrl>
+#include <QUrl>
 
 #include <KProcess>
 
@@ -44,62 +44,59 @@ public:
      * @param dest the path of the destination file, to be created.
      * @param configuration the string of parameters to be fed to the encoder. This implementation
      *        uses the FFmpeg executable, @see http://ffmpeg.org/ffmpeg-doc.html#SEC6
-     * @param the parent QObject.
+     * @param parent the parent QObject.
      */
-    explicit Job( const KUrl &src,
-                  const KUrl &dest,
+    explicit Job( const QUrl &src,
+                  const QUrl &dest,
                   const Transcoding::Configuration &configuration,
-                  QObject *parent = 0 );
+                  QObject *parent = nullptr );
 
     /**
      * Convenience constructor. Creates a Transcoding::Job with the destination file to be
      * placed in the same directory as the source.
      */
-    explicit Job( KUrl &src,
+    explicit Job( QUrl &src,
                   const Transcoding::Configuration &configuration,
-                  QObject *parent = 0 );
+                  QObject *parent = nullptr );
 
     /**
      * Sets the path of the source file.
      * @param src the path of the source file.
      */
-    void setSource( const KUrl &src );
+    void setSource( const QUrl &src );
 
     /**
      * Sets the path of the destination file, to be created.
      * @param dest the path of the destination file.
      */
-    void setDestination( const KUrl &dest );
+    void setDestination( const QUrl &dest );
 
     /**
      * Starts the transcoding job.
      */
-    void start();
+    void start() override;
 
     /**
      * Get the source url.
      */
-    KUrl srcUrl() const { return m_src; }
+    QUrl srcUrl() const { return m_src; }
 
     /**
      * Get the destination url.
      */
-    KUrl destUrl() const { return m_dest; }
+    QUrl destUrl() const { return m_dest; }
 
-private slots:
+private Q_SLOTS:
     void processOutput();
-    /**
-     * Default arguments are for convenience (read: lazyness) so that this can be
-     * connected to QTimer::singleShot()
-     */
-    void transcoderDone( int exitCode = -1, QProcess::ExitStatus exitStatus = QProcess::CrashExit );
+    void transcoderDone( int exitCode, QProcess::ExitStatus exitStatus );
+    void transcoderDoneDefault();
     void init();
 
 private:
     inline qint64 computeDuration( const QString &output );
     inline qint64 computeProgress( const QString &output );
-    KUrl m_src;
-    KUrl m_dest;
+    QUrl m_src;
+    QUrl m_dest;
     Transcoding::Configuration m_configuration;
     KProcess *m_transcoder;
     qint64 m_duration; //in csec
